import { BasicColumn, FormSchema } from '/@/components/Table';
import { optionsOListApi } from '/@/api/tigerapi/wms/otherwarehouse';
import { optionsListApi } from '/@/api/tigerapi/wms/wms_item';
import { h, unref } from 'vue';
import { Tag } from 'ant-design-vue';
import { useI18n } from '/@/hooks/web/useI18n';
import { useLocale } from '/@/locales/useLocale';
const { t: bt } = useI18n();
const { getLocale } = useLocale();

export const columns: BasicColumn[] = [
  {
    title: '单据代码',
    resizable: true,
    sorter: true,
    dataIndex: 'BILLCODE',
    width: 200,
  },
  {
    title: '收货单',
    resizable: true,
    sorter: true,
    dataIndex: 'ERP_BILL_CODE',
    width: 200,
  },
  {
    title: '单据日期',
    resizable: true,
    sorter: true,
    dataIndex: 'BILLDATE',
    width: 180,
  },
  {
    title: bt('创建时间'),
    resizable: true,
    sorter: true,
    dataIndex: 'CREATE_TIME',
    width: 180,
  },
  {
    title: bt('操作时间'),
    resizable: true,
    sorter: true,
    dataIndex: 'UPDATE_TIME',
    width: 180,
  },
  {
    title: '单据状态',
    resizable: true,
    sorter: true,
    dataIndex: 'STATUS',
    width: 180,
    customRender: ({ record }) => {
      const status = record.STATUS;
      let text = '';
      let color = '';
      switch (status) {
        case 0:
          text = '新增';
          color = '#C2C247';
          break;
        case 1:
          text = '作业中';
          color = 'orange';
          break;
        case 2:
          text = '完成';
          color = 'blue';
          break;
        default:
          break;
      }
      return h(Tag, { color: color }, () => text);
    },
  },
  {
    title: '仓库名称',
    resizable: true,
    sorter: true,
    dataIndex: 'SOURCECODE',
    width: 180,
  },
  {
    title: '创建人',
    resizable: true,
    sorter: true,
    dataIndex: 'CREATE_USER',
    width: 180,
  },
  // {
  //   title: '创建时间',
  //   resizable:true,
  //   width: 180,
  // },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'BILLCODE',
    label: '单据代码',
    colProps: { span: 8 },
    component: 'Input',
  },
  {
    field: 'ERP_BILL_CODE',
    label: '收货单',
    colProps: { span: 8 },
    component: 'Input',
  },
  {
    field: 'BILLDATE',
    label: '单据日期',
    colProps: { span: 8 },
    component: 'RangePicker',
  },
  {
    field: 'STATUS',
    label: '单据状态',
    component: 'ApiSelect',
    componentProps: {
      api: optionsOListApi,
      resultField: 'Data',
      labelField: 'Desc',
      valueField: 'Value',
      // onChange: (e, v) => {
      //   alert(e)
      //   console.log('ApiSelect====>:', e, v);
      // },
    },
    colProps: { span: 8 },
  },
];
//其他入库单(WMS)明细
export const columns_D: BasicColumn[] = [
  {
    title: bt('序号'),
    resizable: true,
    sorter: true,
    dataIndex: 'BILLLINE',
    width: 100,
  },
  {
    title: bt('物料编码'),
    resizable: true,
    sorter: true,
    dataIndex: 'ITEM_CODE',
    width: 200,
  },
  {
    title: bt('需求数量'),
    resizable: true,
    sorter: true,
    dataIndex: 'PRQTY',
    width: 100,
  }, {
    title: bt('已发数量'),
    resizable: true,
    sorter: true,
    dataIndex: 'QTY',
    width: 100,
  },
  {
    title: bt('欠入数量'),
    resizable: true,
    sorter: true,
    dataIndex: 'OWEIN_QTY',
    width: 100,
  },
  {
    title: bt('操作时间'),
    resizable: true,
    sorter: true,
    dataIndex: 'CREATE_TIME',
    width: 180,
  },
  {
    title: bt('状态'),
    resizable: true,
    sorter: true,
    dataIndex: 'LINESTATUS',
    width: 180,
    customRender: ({ record }) => {
      console.log('record', record);
      const status = record.LINESTATUS;
      let text = '';
      let color = '';
      switch (status) {
        case 0:
          text = '新增';
          color = '#C2C247';
          break;
        case 1:
          text = '作业中';
          color = 'orange';
          break;
        case 2:
          text = '完成';
          color = 'blue';
          break;
        default:
          break;
      }
      return h(Tag, { color: color }, () => text);
    },
  },
  // {
  //   title: bt('出库仓库代码'),
  //   resizable:true,
  //   width: 200,
  // },
  {
    title: bt('仓库代码'),
    resizable: true,
    sorter: true,
    dataIndex: 'WAREHOUSECODE',
    width: 200,
  },
  {
    title: bt('到货数量'),
    resizable: true,
    sorter: true,
    dataIndex: 'PRQTY',
    width: 200,
  },
  {
    title: bt('入库数量'),
    resizable: true,
    sorter: true,
    dataIndex: 'QTY',
    width: 200,
  },
]

export const columns_S: BasicColumn[] = [
  {
    title: bt('条码'),
    resizable: true,
    sorter: true,
    dataIndex: 'SN',
    width: 200,
  },
  // {
  //   title: bt('单据日期'),
  //   resizable:true,
  //   width: 200,
  // },
  {
    title: bt('物料编码'),
    resizable: true,
    sorter: true,
    dataIndex: 'ITEM_CODE',
    width: 200,
  },
  // {
  //   title: bt('创建时间'),
  //   resizable: true,
  //   sorter: true,
  //   dataIndex: 'CREATE_TIME',
  //   width: 180,
  // },
  {
    title: bt('修改时间'),
    resizable: true,
    sorter: true,
    dataIndex: 'UPDATE_TIME',
    width: 180,
  },
  {
    title: bt('状态'),
    resizable: true,
    sorter: true,
    dataIndex: 'STATUS',
    width: 180,
    customRender: ({ record }) => {
      console.log('record', record);
      const status = record.STATUS;
      let text = '';
      let color = '';
      switch (status) {
        case 0:
          text = '不存在';
          color = 'green';
          break;
        case 10:
          text = '送货中';
          color = 'blue';
          break;
        case 20:
          text = '待检验';
          color = 'green';
          break;
        case 30:
          text = '待入库';
          color = '#C2C247';
          break;
        case 40:
          text = '在库中';
          color = 'blue';
          break;
        case 50:
          text = '已下架';
          color = 'green';
          break;
        case 60:
          text = '已发料';
          color = 'red';
          break;
        case 70:
          text = '已上料';
          color = 'red';
          break;
        case 80:
          text = '已耗尽';
          color = 'green';
          break;
        case 90:
          text = '已退料';
          color = 'green';
          break;
        case 100:
          text = '已发货';
          color = 'green';
          break;
        default:
          break;
      }
      return h(Tag, { color: color }, () => text);
    },
  },

  {
    title: bt('数量'),
    resizable: true,
    sorter: true,
    dataIndex: 'QTY',
    width: 200,
  },
];

export const searchFormSchema_D: FormSchema[] = [
  {
    field: 'ITEM_CODE',
    label: bt('物料编码'),
    colProps: { span: 8 },
    component: 'Input',
  },
  {
    field: 'LINESTATUS',
    label: bt('状态'),
    component: 'ApiSelect',
    colProps: { span: 8 },
    componentProps: {
      api: optionsOListApi,
      resultField: 'Data',
      labelField: unref(getLocale) == 'zh_CN' ? 'Desc' : 'Name',
      valueField: 'Value',
    },
  }
];
export const searchFormSchema_S: FormSchema[] = [
  {
    field: 'ITEM_CODE',
    label: bt('物料编码'),
    colProps: { span: 8 },
    component: 'Input',
  },
  {
    field: 'SN',
    label: bt('条码'),
    colProps: { span: 8 },
    component: 'Input',
  },
  // {
  //   field: 'STATUS',
  //   label: '状态',
  //   component: 'ApiSelect',
  //   colProps: { span: 8 },
  //   defaultValue: 40,
  //   componentProps: {
  //     mode: 'multiple',
  //     api: optionsListApi,
  //     resultField: 'Data',
  //     labelField: 'Desc',
  //     valueField: 'Value',
  //   }
  // },
];
